@@ -6,7 +6,7 @@ class LocationLogHandler(object):
     NAME = 'log_handler'
 
     def __init__(self, arguments, processor_factory):
-        self.logger = arguments['logger']
+        pass
 
     def add_aug(self, trigger_services, output, aug):
-        trigger_services.get_service(LoggingLocationService.NAME).add_logging_aug(self.logger, aug)
+        trigger_services.get_service(LoggingLocationService.NAME).add_logging_aug(aug)
