@@ -217,7 +217,7 @@ class AgentCom(object):
                 # Logging is not safe here, interpreter might be shutting down
                 try:
                     incoming_client_socket.close()
-                except:
+                except:  # Nothing to do as we are already closing
                     pass
 
                 try:
@@ -350,7 +350,7 @@ class AgentCom(object):
                     if msg is not None:
                         self._queue.put(msg)
                     break
-        except:
+        except:  # lgtm[py/catch-base-exception]
             logger.exception("Outgoing thread failed")
 
         finally:
@@ -452,7 +452,7 @@ class AgentCom(object):
                         try:
                             if callback.persistent:
                                 callback.cb(message)
-                        except:
+                        except Exception:  # We ignore errors here, they are high unlikely and the code is too deep
                             pass
                         finally:
                             if callback.persistent:
@@ -463,7 +463,7 @@ class AgentCom(object):
                         try:
                             if not callback.persistent:
                                 callback.cb(message)
-                        except:
+                        except Exception:  # We ignore errors here, they are high unlikely and the code is too deep
                             pass
 
                     self._callbacks[type_name] = persistent_callbacks
