@@ -77,7 +77,7 @@ class _LogRecord(object):
 class Logger(object):
 
     def __init__(self):
-        if ('unittest' in sys.argv[0] or 'pytest' in sys.argv[0]) and ("PythonRook" in os.getcwd()):
+        if sys.argv and ('unittest' in sys.argv[0] or 'pytest' in sys.argv[0]) and ("PythonRook" in os.getcwd()):
             LoggingConfiguration.LOG_TO_STDERR = True
             LoggingConfiguration.LOG_LEVEL = "debug"
 
