@@ -18,7 +18,7 @@ from rook.config import ImportServiceConfig
 
 from rook.serverless import on_lambda
 
-from rook.exceptions.tool_exceptions import RookDependencyError, RookSourceFilePathSuggestion
+from rook.exceptions import RookDependencyError, RookSourceFilePathSuggestion
 
 from rook.file_utils import FileUtils
 
@@ -84,7 +84,7 @@ class ImportService(object):
     def __init__(self, bdb_location_service):
         self._bdb_location_service = bdb_location_service
 
-        self._modules = frozenset(sys.modules.keys())
+        self._modules = sys.modules.copy()
         self._path_cache = {}
         self._post_import_notifications = {}
 
@@ -130,7 +130,7 @@ class ImportService(object):
                         # potentially resulting in CodeNotFound.
                         if import_hook.import_lock.get_recursion_count() == 1:
                             self.evaluate_module_list()
-                    except:
+                    except:  # lgtm[py/catch-base-exception]
                         pass
 
                     return result
@@ -195,9 +195,7 @@ class ImportService(object):
         file_hashes = {}
         with CountingImportLock():
             # Attempt to satisfy notification using known modules
-            for module_name in self._modules:
-                module_object = sys.modules[module_name]
-
+            for module_name, module_object in six.iteritems(self._modules):
                 # Get module details and check if it matches
                 module_filename = self._get_module_path(module_object)
 
@@ -284,21 +282,20 @@ class ImportService(object):
                 return
 
             # Get a fresh list
-            module_names = frozenset(sys.modules.keys())
+            modules = sys.modules.copy()
             # self._modules is only replaced (it's immutable - a frozenset), so there's no need to copy it here,
             # just keep a reference to the current self._modules so we don't start working on a different set
             # mid-loop
             old_modules = self._modules
 
             # For everybody not in the old list, check notifications
-            for module_name in module_names:
-                module = sys.modules[module_name]
+            for module_name, module in six.iteritems(modules):
                 module_filename = self._get_module_path(module)
-                if module_name not in old_modules and self._is_valid_module(module, module_filename):
+                if module_name not in old_modules.keys() and self._is_valid_module(module, module_filename):
                     self._notify_of_new_module(module.__name__, module, module_filename)
 
             # Update the "old" list
-            self._modules = module_names
+            self._modules = modules
 
         except Exception:
             logger.exception("Exception in ImportService")
